datafusion_row::writer

Function write_batch_unchecked

pub fn write_batch_unchecked(
    output: &mut [u8],
    offset: usize,
    batch: &RecordBatch,
    row_idx: usize,
    schema: Arc<Schema>,
) -> Vec<usize>
Append batch from row_idx to output buffer start from offset

Panics

This function will panic if the output buffer doesn’t have enough space to hold all the rows